@@ -55,4 +55,9 @@ bool PAL::openAppSettings()
 bool PAL::checkPermission(int permission)
 {
 	return m_PALImpl->checkPermission(permission);
-}
\ No newline at end of file
+}
+
+bool PAL::isInternetAvailable()
+{
+    return m_PALImpl->isInternetAvailable();
+}
