@@ -79,23 +79,6 @@ PyObject *pal_RegisterNotifyEvent(pal_obj *self, PyObject *args)
 	return Py_None;
 }
 
-PyObject *pal_PollNotifyEvents(pal_obj *self, PyObject *args)
-{
-	PyObject *list = PyList_New(0);
-	std::vector<NotifyCallback> notifyEvents = PAL::Instance()->pollNotifyEvent();
-	for (int i = 0; i < notifyEvents.size(); i++)
-	{
-		PyObject *obj = Py_BuildValue("{s:s,s:s,s:s}",
-									  "name", notifyEvents[i].name,
-									  "type", notifyEvents[i].type,
-									  "id", notifyEvents[i].id);
-
-		PyList_Append(list, obj);
-	}
-	return list;
-}
-
-
 static PyObject *pal_SaveToGallery(pal_obj *self, PyObject *args)
 {
 	char *imgName;
@@ -132,6 +115,12 @@ static PyObject* pal_checkPermission(pal_obj* self, PyObject* args)
 	return PyBool_FromLong(result);
 }
 
+static PyObject* pal_isInternetAvailable(pal_obj* self)
+{
+    bool result = PAL::Instance()->isInternetAvailable();
+    return PyBool_FromLong(result);
+}
+
 
 PyMethodDef pal_methods[] = {
 	{"init", (PyCFunction)pal_Init, METH_NOARGS, palInit_doc},
@@ -140,6 +129,7 @@ PyMethodDef pal_methods[] = {
 	{"saveToGallery", (PyCFunction)pal_SaveToGallery, METH_VARARGS, palSaveToGallery_doc},
 	{"openAppSettings", (PyCFunction)pal_openAppSettings, METH_NOARGS, palOpenAppSettings_doc},
 	{"checkPermission", (PyCFunction)pal_checkPermission, METH_VARARGS, palCheckPermission_doc},
+    {"isInternetAvailable", (PyCFunction)pal_isInternetAvailable, METH_NOARGS, palIsInternetAvailable_doc},
 	{NULL, NULL}};
 
 PyGetSetDef pal_getsets[] = {
