@@ -5,4 +5,4 @@ igePAL
 from igePAL._igePAL import *
 
 PERMISSIONS_REQUEST_CAMERA = 1
-PERMISSIONS_REQUEST_STORAGE = 2
+PERMISSIONS_REQUEST_PHOTO = 2
